# -*- coding: iso-8859-1 -*-
#
# $Id: CorrectAnswer.py,v 1.9 2006/01/31 18:17:23 wfenske Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from AccessControl import ClassSecurityInfo

from Products.Archetypes.public import BaseSchema, Schema, BooleanField, StringField, TextField, SelectionWidget, TextAreaWidget, RichWidget, BaseContent
from Products.Archetypes.Widget import TypesWidget, IntegerWidget, BooleanWidget, StringWidget

from Products.LlsMultipleChoice.config import PROJECTNAME, SKINS_DIR, \
    QUESTION_DIR, QUESTION_TYPES, ANSWER_DIR, \
    ANSWER_TYPES, GLOBALS, PERMISSION_INTERROGATOR, \
    PERMISSION_STUDENT, I18N_DOMAIN
from Products.LlsMultipleChoice.tools import log, registerTypeLogged
from Products.LlsMultipleChoice.AnswerTypes.SelectionAnswer import SelectionAnswer
from Products.LlsMultipleChoice.InlineTextField import InlineTextField

class CorrectAnswer(SelectionAnswer):
    """ An answer that can be either a right or wrong (in the context of
        a question that contains this answer).
    """

    # See comments in 'AbstractQuestionContainer' for an explanation
    # of the function of a schema, therein defined properties (fields) and 
    # internationalization of the widgets
    schema = SelectionAnswer.schema + Schema((
            InlineTextField('comment', # See 'description' property of the widget.
                accessor='getCommentPrivate',
                searchable=True,
                required=False,
                read_permission=PERMISSION_INTERROGATOR,
                allowable_content_types=('text/plain',
                    'text/structured',
                    'text/restructured',
                    'text/html',),
                default_output_type='text/html',
                widget=TextAreaWidget(
                    label='Comment',
                    label_msgid='answer_comment_label',
                    description='A comment on the answer. If the test is set to "instant feedback", ' \
                        'the candidate will see this text in case his/her answer was wrong.',
                    description_msgid='answer_comment_tool_tip',
                    i18n_domain=I18N_DOMAIN),
                validators=('isXML',),
            ),
            BooleanField('correct', # See 'description' property of the widget.
                accessor='isCorrectPrivate',
                default=0,
                searchable=False,
                read_permission=PERMISSION_INTERROGATOR,
                widget=BooleanWidget(
                    label='Correct',
                    label_msgid='correct_label',
                    description='The checkbox should be marked if this is a correct answer.',
                    description_msgid='correct_tool_tip',
                    i18n_domain=I18N_DOMAIN),
            ),
        ),
    )
    
    # Use a custom page template for viewing.
    actions = (
        {
            'id': 'view',
            'action': 'string:${object_url}/correctanswer_view',
            'permissions': (PERMISSION_INTERROGATOR,),
        },
    )
    
    meta_type = portal_type = archetype_name = 'Correct Answer'    
    
    security = ClassSecurityInfo()
    security.declareProtected(PERMISSION_STUDENT, 'isCorrect')
    def isCorrect(self, *args, **kwargs):
        return self.isCorrectPrivate(*args, **kwargs)
        
    security.declareProtected(PERMISSION_STUDENT, 'getComment')
    def getComment(self, *args, **kwargs):
        return self.getCommentPrivate(*args, **kwargs)
    

# Register this type in Zope
registerTypeLogged(CorrectAnswer)
