# -*- coding: iso-8859-1 -*-
#
# $Id: LlsMultipleChoiceTool.py,v 1.3 2005/12/19 12:17:07 mxp Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass
from OFS.SimpleItem import SimpleItem
from Products.CMFCore.utils import UniqueObject, getToolByName
import re

from Products.PageTemplates.GlobalTranslationService import \
     getGlobalTranslationService

from config import I18N_DOMAIN

class LlsMultipleChoiceTool(UniqueObject, SimpleItem):
    """Various utility methods."""

    id = 'llsmc_tool'
    portal_type = meta_type = 'LlsMultipleChoice Tool'
    
    security = ClassSecurityInfo()

    def getContentLang(self, object, domain=I18N_DOMAIN):
        service = getGlobalTranslationService() # Returns a PTSWrapper
        service = service.load(object)          # Get the actual
                                                # PlacelessTranslationService
        availableTranslations = service.getLanguages(domain)
        
        if object.Language() in availableTranslations:
            return object.Language()

        requestLang = self.getAcceptLanguages(object, availableTranslations)
        if requestLang:
            return requestLang
        
        props = getToolByName(object,'portal_properties').site_properties
        return props.default_language

    def getAcceptLanguages(self, object, available):
        acceptable = object.REQUEST.get('HTTP_ACCEPT_LANGUAGE')
        langcode = re.compile(r'^[^;]+')
        
        if acceptable:
            acceptable = acceptable.split(',')
            acceptable = [langcode.match(elt).group(0) for elt in acceptable]
            lang = [l for l in acceptable if l in available]
            if lang: return lang[0]
        return None

    def localizeNumber(self, format, number):
        """A simple method for localized formatting of decimal
        numbers.  Theoretically, one could use locale.format(), but it
        isn't portable enough."""
        if type(number) not in (int, long, float):
            return number
        
        decimalSeparator = self.translate(msgid = 'fraction_delimiter',
                                          domain = I18N_DOMAIN,
                                          default = '.')
        retval = format % number
        return retval.replace('.', decimalSeparator)

    security.declarePublic('getFullNameById')
    def getFullNameById(self, id):
        mtool = self.portal_membership
        member = mtool.getMemberById(id)

        if not member:
            return id
        
        try:
            sn        = member.getProperty('sn')
            givenName = member.getProperty('givenName')
        except:
            fullname = member.getProperty('fullname', '')
            
            if fullname == '':
                return id
            
            if fullname.find(' ') == -1:
                return fullname
            
            sn = fullname[fullname.rfind(' ') + 1:]
            givenName = fullname[0:fullname.find(' ')]
            
        return sn + ', ' + givenName

                       
InitializeClass(LlsMultipleChoiceTool)
