# -*- coding: iso-8859-1 -*-
#
# $Id: QuestionGroup.py,v 1.17 2006/02/28 07:18:51 wfenske Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import random

from AccessControl import ClassSecurityInfo
from Acquisition import *

from Products.Archetypes.public import Schema, BooleanField, StringField, \
     StringWidget, TextField, TextAreaWidget

from Products.LlsMultipleChoice.config import PROJECTNAME, SKINS_DIR, \
     QUESTION_DIR, QUESTION_TYPES, ANSWER_DIR, \
     ANSWER_TYPES, GLOBALS, PERMISSION_INTERROGATOR, \
     PERMISSION_STUDENT, CUSTOM_EVALUATION_FUNCTION_NAME, I18N_DOMAIN
from Products.LlsMultipleChoice.tools import getParent, evalFunString, \
     log, isNumeric, registerTypeLogged
from Products.LlsMultipleChoice.AbstractQuestionContainer \
     import AbstractQuestionContainer

class QuestionGroup(AbstractQuestionContainer):
    """Allows to group several questions into a unit."""
    
    # See comments in 'AbstractQuestionContainer' for an explanation
    # of the function of a schema, therein defined properties (fields) and 
    # internationalization of the widgets
    schema = AbstractQuestionContainer.schema + Schema((
            StringField('title',
                required=False,
                searchable=True,
                default='',
                widget=StringWidget(
                    label_msgid='label_title',
                    description_msgid='title',
                    i18n_domain='plone'),
            ),
        ),)

    meta_type = portal_type = archetype_name = 'MC Question Group'
    content_icon = 'QuestionGroup.png'
    
    security = ClassSecurityInfo()
    
    # The inherited method 'contentValues()' may not be called by just
    # anoybody, directly or indirectly.
    security.declareProtected(PERMISSION_INTERROGATOR, 'contentValues')

    
    # The functions needed for AbstractQuestionContainer,
    # 'getResults', 'setResults', 'isPublic' and
    # 'getEvaluationScripts' don't have to be implemented. They are
    # acquired from the group's parent


    def getCandidatePoints(self, candidateId):
        """Return how many points the candidate got for the questions
        in this container.  If a custom evaluation script has been
        uploaded it will be invoked. Otherwise a default method will
        be used.
            
        @param candidateId The user ID of the candidate whose points
        you want to know."""
        customScript = self.getEvaluationScript(self.archetype_name)
        questions = self.getQuestions(candidateId)
        if(not customScript): # default
            points = 0
            for question in questions:
##                if(not ('getCandidatePoints' in dir(question))):
##                    return None
                if question.archetype_name not in ['MC Question',
                                                   'Points Question',
                                                   'Rating Question']:
                    return None
                questionCandidatePoints = question.getCandidatePoints(
                                            candidateId)
                if not isNumeric(questionCandidatePoints):
                    return None
                points = points + questionCandidatePoints
            return points
        else: # custom
            return evalFunString(customScript, \
                                 CUSTOM_EVALUATION_FUNCTION_NAME, \
                                 [self, candidateId, questions])
        
        
# Register this type in Zope
registerTypeLogged(QuestionGroup)
