# -*- coding: iso-8859-1 -*-
#
# $Id: PointsQuestion.py,v 1.8 2006/01/31 18:17:25 wfenske Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import random

from AccessControl import ClassSecurityInfo

from Acquisition import aq_base, aq_acquire, aq_inner, aq_parent

from Products.Archetypes.public import BaseFolder, BaseFolderSchema, \
     BaseContent, BaseSchema, Schema, BooleanField, BooleanWidget, \
     IntegerField, IntegerWidget, StringField, TextField, SelectionWidget, \
     TextAreaWidget, StringWidget, RichWidget

from Products.LlsMultipleChoice.config import PROJECTNAME, SKINS_DIR, \
    QUESTION_DIR, QUESTION_TYPES, ANSWER_DIR, \
    ANSWER_TYPES, GLOBALS, PERMISSION_INTERROGATOR, \
    PERMISSION_STUDENT, CUSTOM_EVALUATION_FUNCTION_NAME, I18N_DOMAIN
from Products.LlsMultipleChoice.tools import getParent, evalFunString, log, \
     registerTypeLogged
from Products.LlsMultipleChoice.QuestionTypes.BaseQuestion import BaseQuestion
from Products.LlsMultipleChoice.AnswerTypes.CorrectAnswer import CorrectAnswer


class PointsQuestion(BaseQuestion):
    """ A question that can in some way be graded. The candidate's points 
        or the rating he/she gave, can be retieved via the 
        'getCandidatePoints()' method.
    """

    # See comments in 'AbstractQuestionContainer' for an explanation
    # of the function of a schema, therein defined properties (fields) and
    # internationalization of the widgets
    schema = BaseQuestion.schema + Schema((
            IntegerField('points', # See 'description' property of the widget.
                accessor='getPointsPrivate',
                required=True,
                validators=('isPositiveInt',),
                read_permission=PERMISSION_INTERROGATOR,
                widget=IntegerWidget(
                    label='Points',
                    label_msgid='points_label',
                    description='The number of points assigned to this question.',
                    description_msgid='points_tool_tip',
                    i18n_domain=I18N_DOMAIN),
            ),
        ),
    )
    
    # Use a custom page template for viewing.
    actions = (
        {
            'id': 'view',
            'action': 'string:${object_url}/pointsquestion_view',
            'permissions': (PERMISSION_INTERROGATOR,),
        },
    )
    
    allowed_content_types = BaseQuestion.allowed_content_types + \
                            (CorrectAnswer.archetype_name,)
    meta_type = portal_type = archetype_name = 'Points Question'

    security = ClassSecurityInfo()

    security.declareProtected(PERMISSION_STUDENT, 'getPoints')
    def getPoints(self, *args, **kwargs):
        return self.getPointsPrivate(*args, **kwargs)


    def getCandidatePoints(self, candidateId):
        """ Return how many points the user got for this question.

            @param candidateId The user ID of the candidate whose points you want to know.

            If a custom evaluation script has been uploaded it will be
            invoked. Otherwise a default method will be used.
        """
        parent = getParent(self)
        customScript = parent.getEvaluationScript(self.archetype_name)
        answer = parent.getCandidateAnswer(candidateId, self.UID())
        if(not customScript): # default
            return None
        else: # use custom script
            return evalFunString(customScript, CUSTOM_EVALUATION_FUNCTION_NAME, \
                [self, candidateId, answer])


# Register this type in Zopes
registerTypeLogged(PointsQuestion)
