# -*- coding: iso-8859-1 -*-
#
# $Id: RatingQuestion.py,v 1.8 2006/01/31 18:17:25 wfenske Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import random

from AccessControl import ClassSecurityInfo

from Acquisition import aq_base, aq_acquire, aq_inner, aq_parent

from Products.Archetypes.public import BaseFolder, BaseFolderSchema, \
BaseContent, BaseSchema, Schema, BooleanField, BooleanWidget, IntegerField, \
IntegerWidget, StringField, TextField, SelectionWidget, TextAreaWidget, \
StringWidget, RichWidget

from Products.LlsMultipleChoice.config import PROJECTNAME, SKINS_DIR, \
    QUESTION_DIR, QUESTION_TYPES, ANSWER_DIR, \
    ANSWER_TYPES, GLOBALS, PERMISSION_INTERROGATOR, \
    PERMISSION_STUDENT, CUSTOM_EVALUATION_FUNCTION_NAME, I18N_DOMAIN
from Products.LlsMultipleChoice.tools import getParent, evalFunString, log, \
     registerTypeLogged
from Products.LlsMultipleChoice.QuestionTypes.SelectionQuestion \
     import SelectionQuestion
from Products.LlsMultipleChoice.QuestionTypes.PointsQuestion \
     import PointsQuestion
from Products.LlsMultipleChoice.AnswerTypes.SelectionAnswer \
     import SelectionAnswer


class RatingQuestion(SelectionQuestion, PointsQuestion):
    """ A question that asks the candidate to give a rating for something.
        'points', in this class, is the maximum rating. The answers are 
        the possible ratings (e.g. 'very good', 'OK', 'bad'). 'getCandidatePoints' 
        returns which rating(s) has (have) been selected.
    """

    # See comments in 'AbstractQuestionContainer' for an explanation
    # of the function of a schema, therein defined properties (fields) and
    # internationalization of the widgets
    schema = SelectionQuestion.schema + PointsQuestion.schema

    # Use a custom page template for viewing.
    actions = (
        {
            'id': 'view',
            'action': 'string:${object_url}/ratingquestion_view',
            'permissions': (PERMISSION_INTERROGATOR,),
        },
    )

    # Only Answer objects may be put into this folder.
    allowed_content_types = (SelectionAnswer.archetype_name,)
    meta_type = portal_type = archetype_name = 'Rating Question'


    def getCandidatePoints(self, candidateId):
        """ Return how many points the user got for this question.

            @param candidateId The user ID of the candidate whose points you want to know.

            If a custom evaluation script has been uploaded it will be
            invoked. Otherwise a default method will be used.
        """
        parent = getParent(self)
        customScript = parent.getEvaluationScript(self.archetype_name)
        candidateAnswer = parent.getCandidateAnswer(candidateId, self.UID())
        if(not customScript): # default
            if candidateAnswer is None:
                return None
            else:
                if(candidateAnswer == None):
                    candidateAnswer = []
                suggestedAnswers = self.getAnswers(candidateId)
                selectedAnswers = [answer for answer in suggestedAnswers if (answer.getId() in candidateAnswer)]
                if(not selectedAnswers):
                    # Nothig has been selected
                    return None
                elif(len(selectedAnswers) > 1):
                    # If multiple answers have been selected, return a list 
                    # with the answers' texts.
                    return map((lambda(answer):(answer.getAnswer())), selectedAnswers)
                else:
                    # No multiple selection -> Return the selected answer's text
                    selectedAnswerText = (selectedAnswers[0]).getAnswer()
                    try:
                        # If he answer is a number, return it as a number.
                        return float(selectedAnswerText)
                    except:
                        # No number -> return just the text.
                        return selectedAnswerText
        else: # use custom script
            return evalFunString(customScript, CUSTOM_EVALUATION_FUNCTION_NAME, \
                [self, candidateId, answer])


# Register this type in Zopes
registerTypeLogged(RatingQuestion)
