# -*- coding: iso-8859-1 -*-
#
# $Id: SelectionQuestion.py,v 1.6 2006/01/31 18:17:25 wfenske Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import random

from AccessControl import ClassSecurityInfo

from Acquisition import aq_base, aq_acquire, aq_inner, aq_parent

from Products.Archetypes.public import BaseFolder, BaseFolderSchema, \
BaseContent, BaseSchema, Schema, BooleanField, BooleanWidget, IntegerField, IntegerWidget, StringField, \
TextField, SelectionWidget, TextAreaWidget, StringWidget, RichWidget

from Products.LlsMultipleChoice.config import PROJECTNAME, SKINS_DIR, \
    QUESTION_DIR, QUESTION_TYPES, ANSWER_DIR, \
    ANSWER_TYPES, GLOBALS, PERMISSION_INTERROGATOR, \
    PERMISSION_STUDENT, CUSTOM_EVALUATION_FUNCTION_NAME, I18N_DOMAIN
from Products.LlsMultipleChoice.tools import evalFunString, log, \
     registerTypeLogged
from Products.LlsMultipleChoice.QuestionTypes.BaseQuestion \
     import BaseQuestion
from Products.LlsMultipleChoice.AnswerTypes.SelectionAnswer \
     import SelectionAnswer


class SelectionQuestion(BaseQuestion):
    """ A question that allows the candidate to select one or more of the 
        predefined answers contained in the question (BaseQuestion is
        derived from 'BaseFolder').
    """

    # See comments in 'AbstractQuestionContainer' for an explanation
    # of the function of a schema, therein defined properties (fields) and
    # internationalization of the widgets
    schema = BaseQuestion.schema + Schema((
            BooleanField('allowMultipleSelection',
                # If 'allowMultipleSelection' is True, this is a multiple answer
                # question, i.e. one where more than one answer can be true. Otherwise
                # it is a multiple choice question, i.e. exactly only one answer is
                # correct.
                #   The question_view template is designed to support this. When
                # 'allowMultipleSelection' is True, radio buttons will be generated.
                # If not, check boxes will be shown.
                #   See also 'description' property of the widget.
                accessor='isAllowMultipleSelection',
                default=1,
                searchable=False,
                widget=BooleanWidget(
                    label='Allow Multiple Selection',
                    label_msgid='allow_multiple_selection_label',
                    description='If the selection of multiple answers should be possible, mark this checkbox.',
                    description_msgid='allow_multiple_selection_tool_tip',
                    i18n_domain=I18N_DOMAIN),
            ),
        ),
    )
    
    # Use a custom page template for viewing.
    actions = (
        {
            'id': 'view',
            'action': 'string:${object_url}/selectionquestion_view',
            'permissions': (PERMISSION_INTERROGATOR,),
        },
    )
    
    allowed_content_types = (SelectionAnswer.archetype_name,)
    meta_type = portal_type = archetype_name = 'Selection Question'
    


# Register this type in Zopes
registerTypeLogged(SelectionQuestion)
