# -*- coding: iso-8859-1 -*-
#
# $Id: config.py,v 1.13 2006/02/16 17:12:42 mxp Exp $
#
# Copyright  2004 Otto-von-Guericke-Universitt Magdeburg
#
# This file is part of LlsMultipleChoice.
#
# LlsMultipleChoice is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LlsMultipleChoice is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LlsMultipleChoice; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

""" This script contains the global constants for the
'LlsMultipleChoice' Product."""

import os
from Products.CMFCore.permissions import setDefaultRoles, AddPortalContent, \
     ModifyPortalContent, View
from OFS.PropertyManager import PropertyManager
from Products.CMFCore.utils import getToolByName


def makeTypeList(relativeDir):
    """ Returns a sequence of all the python files in a directory 
        specified by "relativeDir".
    """
    ret = os.listdir(os.path.dirname(__file__)+'/'+ relativeDir)
    ret = [type[:-3] for type in ret \
            if (type.endswith('.py') \
                and not type.startswith('__'))]
    return ret

# The name of the Product
PROJECTNAME = 'LlsMultipleChoice'

SKINS_DIR = 'skins'

QUESTION_DIR = 'QuestionTypes'
QUESTION_TYPES = makeTypeList(QUESTION_DIR)
                
ANSWER_DIR = 'AnswerTypes'
ANSWER_TYPES = makeTypeList(ANSWER_DIR)

GLOBALS = globals()

# Permissions
PERMISSION_INTERROGATOR = ModifyPortalContent
PERMISSION_STUDENT = View
DEFAULT_ADD_CONTENT_PERMISSION = AddPortalContent
ADD_MCTEST_PERMISSION = '%s: Add MC Test' % PROJECTNAME

setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner',))

ADD_CONTENT_PERMISSIONS = {
    'MultipleChoiceTest': ADD_MCTEST_PERMISSION,
}

setDefaultRoles(ADD_MCTEST_PERMISSION, ('Manager', 'Owner',))


I18N_DOMAIN = 'llsMultipleChoice'

# The name of custom evaluation functions.
CUSTOM_EVALUATION_FUNCTION_NAME = 'getCandidatePointsCustom'

# Types which support custom evaluation functions
CUSTOM_EVALUATION_TYPES = ['MC Test', 'MC Question Group', 'MC Question']

def addSiteProperties(portal):
    """ adds site_properties in portal_properties """
    id = PROJECTNAME.lower()+'_properties'
    title = 'Site wide properties'
    p=PropertyManager('id')
    if id not in portal.portal_properties.objectIds():
        portal.portal_properties.addPropertySheet(id, title, p)
    p=getattr(portal.portal_properties, id)

##    if not hasattr(p,'allowAnonymousViewAbout'):
##        safeEditProperty(p, 'allowAnonymousViewAbout', 1, 'boolean')
##    if not hasattr(p,'localTimeFormat'):
##        safeEditProperty(p, 'localTimeFormat', '%Y-%m-%d', 'string')
##    if not hasattr(p,'localLongTimeFormat'):
##        safeEditProperty(p, 'localLongTimeFormat', '%Y-%m-%d %H:%M', 'string')
##    if not hasattr(p,'default_language'):
##        safeEditProperty(p, 'default_language', 'en', 'string')
##    if not hasattr(p,'default_charset'):
##        safeEditProperty(p, 'default_charset', 'utf-8', 'string')
##    if not hasattr(p,'use_folder_tabs'):
##        safeEditProperty(p, 'use_folder_tabs',('Folder',), 'lines')
##    if not hasattr(p,'use_folder_contents'):
##        safeEditProperty(p, 'use_folder_contents',[], 'lines')
##    if not hasattr(p,'ext_editor'):
##        safeEditProperty(p, 'ext_editor', 0, 'boolean')
##    if not hasattr(p, 'available_editors'):
##        safeEditProperty(p, 'available_editors', ('None', ), 'lines')
##    if not hasattr(p, 'allowRolesToAddKeywords'):
##        safeEditProperty(p, 'allowRolesToAddKeywords', ['Manager', 'Reviewer'], 'lines')
##    if not hasattr(p, 'auth_cookie_length'):
##        safeEditProperty(p, 'auth_cookie_length', 0, 'int')
##    if not hasattr(p, 'calendar_starting_year'):
##        safeEditProperty(p, 'calendar_starting_year', 1999, 'int')
##    if not hasattr(p, 'calendar_future_years_available'):
##        safeEditProperty(p, 'calendar_future_years_available', 5, 'int'
